/**
 * Copyright (c) 1996 Sun Microsystems, Inc. All Rights Reserved.
 *
 * Sun grants you ("Licensee") a non-exclusive, royalty free, license to use,
 * modify and redistribute this software in source and binary code form,
 * provided that i) this copyright notice and license appear on all copies of
 * the software; and ii) Licensee does not utilize the software in a manner
 * which is disparaging to Sun.
 *
 * This software is provided "AS IS," without a warranty of any kind. ALL
 * EXPRESS OR IMPLIED CONDITIONS, REPRESENTATIONS AND WARRANTIES, INCLUDING ANY
 * IMPLIED WARRANTY OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE OR
 * NON-INFRINGEMENT, ARE HEREBY EXCLUDED. SUN AND ITS LICENSORS SHALL NOT BE
 * LIABLE FOR ANY DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING
 * OR DISTRIBUTING THE SOFTWARE OR ITS DERIVATIVES. IN NO EVENT WILL SUN OR ITS
 * LICENSORS BE LIABLE FOR ANY LOST REVENUE, PROFIT OR DATA, OR FOR DIRECT,
 * INDIRECT, SPECIAL, CONSEQUENTIAL, INCIDENTAL OR PUNITIVE DAMAGES, HOWEVER
 * CAUSED AND REGARDLESS OF THE THEORY OF LIABILITY, ARISING OUT OF THE USE OF
 * OR INABILITY TO USE SOFTWARE, EVEN IF SUN HAS BEEN ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGES.
 *
 * This software is not designed or intended for use in on-line control of
 * aircraft, air traffic, aircraft navigation or aircraft communications; or in
 * the design, construction, operation or maintenance of any nuclear
 * facility. Licensee represents and warrants that it will not use or
 * redistribute the Software for such purposes.
 */
package examples.rmi.stock;

import weblogic.rmi.*;

/**
 * This class is used with the WebLogic RMI Stock example package.
 * The StockWatch remote interface is used to register interest in
 * receiving stock updates.
 * <p>
 * The classes in this package have been adapted to work with
 * WebLogic RMI from WebLogic.
 *
 * @author Adapted 1997 by WebLogic, Inc.
 */
public interface StockWatch extends weblogic.rmi.Remote {
  
  /**
   * Requests notification of stock updates.
   *
   * @param stock             Stock name
   * @param obj               Remote object to be notified
   * @return                  Latest update of the stock
   * @exception               examples.rmi.stock.StockNotFoundException
   *                          if stock is not known
   * @exception               weblogic.rmi.RemoteException
   *                          if some communication failure occurs
   */
  Stock watch(String stock, StockNotify obj) throws StockNotFoundException, RemoteException;
  
  /**
   * Cancels a request for stock updates for a particular stock.
   * 
   * @param stock             Stock name
   * @param obj               Remote object canceling the notification
   * @exception               weblogic.rmi.RemoteException
   *                          if some communication failure occurs
   */
  void cancel(String stock, StockNotify obj) throws RemoteException;
  
  /**
   * Returns an array of stock update information for the stocks
   * already registered by the remote object, or null if the object
   * is not watching any stocks.
   * 
   * @param obj               Remote object
   * @return                  List of stocks, or null
   * @exception               weblogic.rmi.RemoteException
   *                          if some communication failure occurs
   */
  Stock[] list(StockNotify obj) throws RemoteException;
  
  /**
   * Cancels all requests for stock updates for the remote object.
   *
   * @param obj               Remote object canceling the request
   * @exception               weblogic.rmi.RemoteException
   *                          if some communication failure occurs
   */
  void cancelAll(StockNotify obj) throws RemoteException;
}

